awsha

package
v0.0.0-...-9dabdb3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 23, 2017 License: Apache-2.0 Imports: 6 Imported by: 0

Documentation

Overview

Package implements OCCM Working Environments API (AWS-HA).

Package implements OCCM Working Environments API (AWS-HA).

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type AWSHAWorkingEnvironmentAPI

type AWSHAWorkingEnvironmentAPI struct {
	*client.Client
}

VSA Working environment API

func New

New creates a new OCCM VSA Working Environment API client

func (*AWSHAWorkingEnvironmentAPI) ChangeVolumeTier

func (api *AWSHAWorkingEnvironmentAPI) ChangeVolumeTier(workenvId, svmName, volumeName string, request *workenv.ChangeVolumeTierRequest) (string, error)

ChangeVolumeTier changes tier for the given volume

func (*AWSHAWorkingEnvironmentAPI) CloneVolume

func (api *AWSHAWorkingEnvironmentAPI) CloneVolume(workenvId, svmName, volumeName string, request *workenv.VolumeCloneRequest) (string, error)

CloneVolume clones the given volume

func (*AWSHAWorkingEnvironmentAPI) CreateVolume

func (api *AWSHAWorkingEnvironmentAPI) CreateVolume(createAggregateIfNotFound bool, request *vsa.VSAVolumeCreateRequest) (string, error)

CreateVolume creates a volume for the given request

func (*AWSHAWorkingEnvironmentAPI) DeleteVolume

func (api *AWSHAWorkingEnvironmentAPI) DeleteVolume(workenvId, svmName, volumeName string) (string, error)

DeleteVolume deletes the given volume

func (*AWSHAWorkingEnvironmentAPI) GetAggregates

func (api *AWSHAWorkingEnvironmentAPI) GetAggregates(workenvId string) ([]workenv.AggregateResponse, error)

GetAggregates retrieves a list of all aggregates for a given working environment

func (*AWSHAWorkingEnvironmentAPI) GetVolume

func (api *AWSHAWorkingEnvironmentAPI) GetVolume(workenvId, volumeName string) (*workenv.VolumeResponse, error)

GetVolume retrieves a volume for the given working environment and volume name

func (*AWSHAWorkingEnvironmentAPI) GetVolumes

func (api *AWSHAWorkingEnvironmentAPI) GetVolumes(workenvId string) ([]workenv.VolumeResponse, error)

GetVolumes retrieves a list of all volumes for a given working environment

func (*AWSHAWorkingEnvironmentAPI) ModifyVolume

func (api *AWSHAWorkingEnvironmentAPI) ModifyVolume(workenvId, svmName, volumeName string, request *workenv.VolumeModifyRequest) (string, error)

ModifyVolume modifies the given volume

func (*AWSHAWorkingEnvironmentAPI) MoveVolume

func (api *AWSHAWorkingEnvironmentAPI) MoveVolume(workenvId, svmName, volumeName string, request *workenv.VolumeMoveRequest) (string, error)

MoveVolume moves the given volume

func (*AWSHAWorkingEnvironmentAPI) QuoteVolume

QuoteVolume quotes a volume for the given request

Jump to